#
# Konstantin Volkov <wolf@virtuozzo.com>
#
# Copyright (c) 2015-2017 Parallels IP Holdings GmbH
# Copyright (c) 2017-2019 Virtuozzo International GmbH. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Virtuozzo
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Virtuozzo.
#
import string

from pykickstart.base import *
from pykickstart.errors import *
from pykickstart.options import *

import gettext
_ = lambda x: gettext.ldgettext("pykickstart", x)

class PSBM5_Prlnet(KickstartCommand):
    removedKeywords = KickstartCommand.removedKeywords
    removedAttrs = KickstartCommand.removedAttrs

    def __init__(self, writePriority=0, *args, **kwargs):
        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
        self.op = self._getParser()
        self.ip_scope_start = kwargs.get("ip-scope-start", "")
        self.ip_scope_end = kwargs.get("ip-scope-end", "")
        self.name = kwargs.get("name", "")
        self.ip = kwargs.get("ip", "")
        self.dhcp_ip = kwargs.get("dhcp-ip", "")

    def __str__(self):
        retval = KickstartCommand.__str__(self)

        if self.ip_scope_start or self.ip_scope_end or self.name or self.ip or self.dhcp_ip:
            retval += "prlnet"

            if self.ip_scope_start:
                retval +=" --ip-scope-start=%s" % self.ip_scope_start

            if self.ip_scope_end:
                retval +=" --ip-scope-end=%s" % self.ip_scope_end

            if self.name:
                retval +=" --name=%s" % self.name

            if self.ip:
                retval +=" --ip=%s" % self.ip

            if self.dhcp_ip:
                retval +=" --dhcp-ip=%s" % self.dhcp_ip

            retval += "\n"

        return retval

    def _getParser(self):
        op = KSOptionParser()
        op.add_option("--ip-scope-start", dest="ip_scope_start", action="store")
        op.add_option("--ip-scope-end", dest="ip_scope_end", action="store")
        op.add_option("--name", dest="name", action="store")
        op.add_option("--ip", dest="ip", action="store")
        op.add_option("--dhcp-ip", dest="dhcp_ip", action="store")
        return op

    def parse(self, args):
        if len(args) == 0:
            raise KickstartValueError, formatErrorMsg(self.lineno, msg=_("Command %s requires at least one argument") % "prlnet")

        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)

        self._setToSelf(self.op, opts)

        return self

class VZ7_Prlnet(PSBM5_Prlnet):
    def __init__(self, writePriority=100, *args, **kwargs):
        PSBM5_Prlnet.__init__(self, writePriority=writePriority, *args, **kwargs)
        self.used = False
        self.ip6_scope_start = kwargs.get("ip6-scope-start", "")
        self.ip6_scope_end = kwargs.get("ip6-scope-end", "")
        self.ip6 = kwargs.get("ip6", "")
        self.dhcp_ip6 = kwargs.get("dhcp-ip6", "")
        self.dhcp_server = kwargs.get("dhcp-server", "")
        self.dhcp6_server = kwargs.get("dhcp6-server", "")

    def _getParser(self):
        op = PSBM5_Prlnet._getParser(self)
        op.add_option("--ip6-scope-start", dest="ip6_scope_start", action="store")
        op.add_option("--ip6-scope-end", dest="ip6_scope_end", action="store")
        op.add_option("--ip6", dest="ip6", action="store")
        op.add_option("--dhcp-ip6", dest="dhcp_ip6", action="store")
        op.add_option("--dhcp-server", dest="dhcp_server", action="store")
        op.add_option("--dhcp6-server", dest="dhcp6_server", action="store")
        return op

    def __str__(self):
        retval = PSBM5_Prlnet.__str__(self)

        if self.ip6_scope_start:
            retval += " --ip6-scope-start=%s" % self.ip6_scope_start

        if self.ip6_scope_end:
            retval += " --ip6-scope-end=%s" % self.ip6_scope_end

        if self.ip6:
            retval += " --ip6=%s" % self.ip6

        if self.dhcp_ip6:
            retval += " --dhcp-ip6=%s" % self.dhcp_ip6

        if self.dhcp_server:
            retval += " --dhcp-server=%s" % self.dhcp_server

        if self.dhcp6_server:
            retval += " --dhcp6-server=%s" % self.dhcp6_server

        if retval:
            retval += "\n"

        return retval

    def parse(self, args):
        PSBM5_Prlnet.parse(self, args)
        if self.ip_scope_start or self.ip_scope_end or self.name or self.ip or self.dhcp_ip or \
            self.ip6_scope_start or self.ip6_scope_end or self.ip6 or self.dhcp_ip6 or \
            self.dhcp_server or self.dhcp6_server:
            self.used = True
