#
# Konstantin Volkov <wolf@virtuozzo.com>
#
# Copyright (c) 2015-2017 Parallels IP Holdings GmbH
# Copyright (c) 2017-2019 Virtuozzo International GmbH. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Virtuozzo
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Virtuozzo.
#
import string

from pykickstart.base import *
from pykickstart.errors import *
from pykickstart.options import *

import gettext
_ = lambda x: gettext.ldgettext("pykickstart", x)

class PSBM5_Pvamn(KickstartCommand):
    removedKeywords = KickstartCommand.removedKeywords
    removedAttrs = KickstartCommand.removedAttrs

    def __init__(self, writePriority=0, *args, **kwargs):
        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
        self.op = self._getParser()
        self.ip = kwargs.get("ip", "")
        self.hostname = kwargs.get("hostname", "")
        self.pswd = kwargs.get("pswd", "")

    def __str__(self):
        retval = KickstartCommand.__str__(self)

        if self.ip or self.hostname or self.pswd:
            retval += "pvamn"

            if self.ip:
                retval += " --ip=%s" % self.ip
            if self.hostname:
                retval += " --hostname=%s" % self.hostname
            if self.pswd:
                retval += " --pswd=%s" % self.pswd

            retval += "\n"

        return retval

    def _getParser(self):
        op = KSOptionParser()
        op.add_option("--ip", dest="ip", action="store")
        op.add_option("--hostname", dest="hostname", action="store")
        op.add_option("--pswd", dest="pswd", action="store")
        return op

    def parse(self, args):
        if len(args) == 0:
            raise KickstartValueError, formatErrorMsg(self.lineno, msg=_("Command %s requires at least one argument") % "vznetcfg")

        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)

        self._setToSelf(self.op, opts)

        return self

class VZ7_Pvamn(PSBM5_Pvamn):
    def parse(self, args):
        warnings.warn("The pvamn parameter is not used anymore and will be ignored.")
