#
# Konstantin Volkov <wolf@virtuozzo.com>
#
# Copyright (c) 2017 Parallels IP Holdings GmbH
# Copyright (c) 2017-2019 Virtuozzo International GmbH. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Virtuozzo
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Virtuozzo.
#

from pykickstart.base import *
from pykickstart.errors import *
from pykickstart.options import *

import gettext
import warnings
_ = lambda x: gettext.ldgettext("pykickstart", x)

class VZ7_RegisterVStorageUI(KickstartCommand):
    def __init__(self, writePriority=0, *args, **kwargs):
        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
        self.op = self._getParser()

        self.ui_addr = kwargs.get("ui_addr", "")
        self.token = kwargs.get("token", "")

    def __str__(self):
        retval = KickstartCommand.__str__(self)

        if not self.enabled:
            return retval

        retval += "register_vstorage_ui"

        if self.ui_addr:
            retval += " --ui_addr=%s" % self.ui_addr

        if self.token:
            retval += " --token=%s" % self.token

        return retval + '\n'

    @property
    def enabled(self):
        return self.ui_addr

    def _getParser(self):
        op = KSOptionParser()
        op.add_option("--ui_addr", action="store", dest="ui_addr", default="")
        op.add_option("--token", action="store", dest="token", default="")

        return op

    def parse(self, args):
        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)
        self._setToSelf(self.op, opts)

        if not self.ui_addr:
            raise KickstartValueError, formatErrorMsg(self.lineno,
                msg=_("vaagent requires UI ip or hostname for registration"))

        if not self.token:
            warnings.warn(_("UI token missed. Will be able to register only in localhost UI."))

        return self
